declare const conversionModule: {
    state: {
        datasets: {};
        distributions: never[];
        catalogues: {};
        deleteDistributionInline: boolean;
    };
    getters: {
        /**
         * Returns raw values for given property, page and distribution
         * @param state
         * @param0 Object containing property, page and distribution id
         * @returns Object conatining form values for given property, distribution and page
         */
        getRawValues: (state: any) => ({ property }: {
            property: any;
        }) => any;
        /**
         * Provides property data
         * @param state
         * @param property Property of wanted data
         * @returns Object containing all values of given property
         */
        getData: (state: any) => (property: any) => {};
    };
    actions: {
        /**
         * Saves values from input form to vuex store
         * @param param0
         * @param param1 Object containing property, page, distrbution id and form values
         */
        saveFormValues({ commit }: {
            commit: any;
        }, { property, values }: {
            property: any;
            values: any;
        }): void;
        /**
         * Saving existing values from localStorage to vuex store
         * @param {*} param0
         * @param {*} param1 Object containing property (datasets/catalogues) and subpage (when curren tprofile is distributions)
         */
        saveLocalstorageValues({ commit }: {
            commit: any;
        }, property: any): void;
        /**
         * Fetches data, writes it to a dataset and calls method for actual conversion to input format
         * @param param0
         * @param param1 Object containing endpoint and token for data fetching as well as property
         */
        convertToInput({ commit, rootGetters }: {
            commit: any;
            rootGetters: any;
        }, { endpoint, token, property }: {
            endpoint: any;
            token: any;
            property: any;
        }): Promise<void>;
        /**
         * Merges store data and converts the given input values into RDF format
         * @param state
         * @param property Object containing all values within nested objects for each page of the frontend
         * @returns Data values in RDF format
         */
        convertToRDF({ state, rootGetters }: {
            state: any;
            rootGetters: any;
        }, { property }: {
            property: any;
        }): undefined;
        /**
         * Calls mutation to clear values and store
         * @param param0
         */
        clearAll({ commit }: {
            commit: any;
        }): void;
    };
    mutations: {
        /**
         * Saves input values from form into vuex as well as into localStorage of browser
         * @param state
         * @param param1 Object containing the property, page and values of input form
         */
        saveFormValuesToStore(state: any, { property, values }: {
            property: any;
            values: any;
        }): void;
        /**
        * Save input form values from localStorage into vuex store
        * @param {*} state
        * @param {String} property Property name the data should be saved to (datasets/distributions/catalogues)
        */
        saveFromLocalstorage(state: any, property: any): void;
        /**
         * Converts RDF data into input form data
         * @param state
         * @param param1 Object containing data and property and state
         */
        saveLinkedDataToStore(state: any, { property, data, specification }: {
            property: any;
            data: any;
            specification: any;
        }): void;
        resetStore(state: any): void;
    };
};
export default conversionModule;
