declare const module: {
    namespaced: boolean;
    state: {
        authenticated: boolean;
        rtptoken: string;
        keycloak: null;
        userData: {
            authToken: string;
            rtpToken: string;
            userName: string;
            permissions: never[];
            drafts: never[];
            roles: never[];
        };
        isEditMode: boolean;
        isDraft: boolean;
    };
    actions: {
        authLogin({ commit }: {
            commit: any;
        }, authenticated: any): void;
        authLogout({ commit }: {
            commit: any;
        }): void;
        rtpToken({ commit }: {
            commit: any;
        }, rtptoken: any): void;
        setKeycloak({ commit }: {
            commit: any;
        }, keycloak: any): void;
        /**
         * Updates user data according to an authentication token and by supplying neccessary
         * information to retrieve tFhe user's permissions as well as their drafts.
         * @param {*} commit
         * @param {Object} params
         * @returns {Promise<Object>}
         */
        updateUserData({ commit, dispatch }: {
            commit: any;
            dispatch: any;
        }, { authToken, rtpToken, hubUrl }: {
            authToken: any;
            rtpToken: any;
            hubUrl: any;
        }): Promise<{}>;
        updateUserDrafts({ commit, state }: {
            commit: any;
            state: any;
        }): Promise<void>;
        createDataset({ commit }: {
            commit: any;
        }, actionParams: any): Promise<void>;
        /**
         * Creates a draft dataset
         * @param {*} commit
         * @param {object} dataset - The dataset object
         * @param {string} dataset.id - The ID of the dataset
         * @param {string} dataset.catalog - The ID of the dataset
         * @param {object} dataset.description - The description object of the dataset containing different locales
         * @param {object} dataset.title - The title object of the dataset containing different locales
         * @param {object} dataset.body - the JSON-LD representation of the dataset
         * @returns {Promise<Object>}
         */
        createUserDraft({ commit }: {
            commit: any;
        }, { id, catalog, description, title, body, }: {
            id: any;
            catalog: any;
            description?: {
                en: string;
            } | undefined;
            title?: {
                en: string;
            } | undefined;
            body?: {} | undefined;
        }): Promise<any>;
        deleteUserDraftById({ commit, state }: {
            commit: any;
            state: any;
        }, { id, catalog }: {
            id: any;
            catalog: any;
        }): Promise<any>;
        publishUserDraftById({ commit, state }: {
            commit: any;
            state: any;
        }, { id, catalog, body }: {
            id: any;
            catalog: any;
            body?: {} | undefined;
        }): Promise<any>;
        duplicateDataset({ commit, state }: {
            commit: any;
            state: any;
        }, { id, newId, catalog, url }: {
            id: any;
            newId: any;
            catalog: any;
            url: any;
        }): Promise<void>;
        publishUserDraft({ dispatch }: {
            dispatch: any;
        }, { id, catalog, body }: {
            id: any;
            catalog: any;
            body: any;
        }): Promise<any>;
        putDatasetToDraft({ commit }: {
            commit: any;
        }, { id, catalog, title, description, }: {
            id: any;
            catalog: any;
            title: any;
            description: any;
        }): Promise<any>;
        setIsEditMode({ commit }: {
            commit: any;
        }, bool: any): void;
        setIsDraft({ commit }: {
            commit: any;
        }, bool: any): void;
        createPersistentIdentifier({ commit }: {
            commit: any;
        }, { id, catalog, type }: {
            id: any;
            catalog: any;
            type?: string | undefined;
        }): Promise<any>;
        populateDraftAndEdit({ commit }: {
            commit: any;
        }): void;
        createCatalogue({ commit }: {
            commit: any;
        }, actionParams: any): Promise<void>;
    };
    mutations: {
        SECURITY_AUTH(state: any, authenticated: any): void;
        RTP_TOKEN(state: any, rtpToken: any): void;
        SET_KEYCLOAK(state: any, keycloak: any): void;
        SET_USER_DATA(state: any, userData: any): void;
        UPDATE_USER_DATA_PENDING(state: any): void;
        UPDATE_USER_DATA_SUCCESS(state: any): void;
        UPDATE_USER_DATA_ERROR(state: any): void;
        CREATE_USER_DRAFT(state: any, { id, catalog, title, description, }: {
            id: any;
            catalog: any;
            title: any;
            description: any;
        }): void;
        PUT_DATASET_TO_DRAFT(state: any, { id, catalog, title, description, }: {
            id: any;
            catalog: any;
            title: any;
            description: any;
        }): void;
        DELETE_USER_DRAFT(state: any, id: any): void;
        CHANGE_IS_EDIT_MODE(state: any, bool: any): void;
        CHANGE_IS_DRAFT(state: any, bool: any): void;
        PREDEFINE_DRAFT_AND_EDIT(state: any): void;
    };
    getters: {
        securityAuth: (state: any) => any;
        getRTPToken: (state: any) => any;
        getKeycloak: (state: any) => any;
        getUserData: (state: any) => any;
        getUserName: (state: any) => any;
        /**
         * @description Get all catalogs associated to the user where they have access to.
         * @returns {Array} Array of catalogs
         */
        getUserCatalogs: (state: any) => any;
        /**
         * @description Get all catalog IDs associated to the user where they have access to.
         */
        getUserCatalogIds: (state: any, getters: any) => any;
        getUserDrafts: (state: any) => any;
        getUserDraftIds: (state: any) => any;
        getIsEditMode: (state: any) => any;
        getIsDraft: (state: any) => any;
    };
};
export default module;
